==> wormux-0.7.9.tar.gz: wormux-0.7.9/src/network/distant_cpu.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Handle distant computers
 *****************************************************************************/

#ifndef DISTANT_CPU_H
#define DISTANT_CPU_H
//-----------------------------------------------------------------------------
#include <SDL_net.h>
#include <SDL_thread.h>
#include <SDL_mutex.h>
#include "../include/base.h" 
#include <list>
#include <string>
#include "../include/action.h" 
//-----------------------------------------------------------------------------
class DistantComputer
{
  SDL_mutex* sock_lock;
  TCPsocket sock;
  std::list<std::string> owned_teams;
  
public:
  DistantComputer(TCPsocket new_sock);
  ~DistantComputer();

  bool SocketReady();
  int ReceiveDatas(char* & buf);
  void SendDatas(char* paket, int size);

  std::string GetAdress();
  std::string nickname;

  void ManageTeam(Action* team);
  void SendChatMessage(Action* a);
};

#endif

==> wormux_0.8.orig.tar.gz: wormux-0.8/src/network/distant_cpu.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2008 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Handle distant computers
 *****************************************************************************/

#ifndef DISTANT_CPU_H
#define DISTANT_CPU_H
//-----------------------------------------------------------------------------
#include <SDL_net.h>
#include "include/base.h"
#include <list>
#include <string>
//-----------------------------------------------------------------------------

struct SDL_mutex;
class Action;

class DistantComputer
{
 public:
  typedef enum {
    STATE_ERROR,
    STATE_INITIALIZED,
    STATE_READY,
    STATE_CHECKED
  } state_t;

 private:
  /* If you need this, implement it (correctly)*/
  DistantComputer(const DistantComputer&);
  const DistantComputer& operator=(const DistantComputer&);
  /*********************************************/

  SDL_mutex* sock_lock;
  TCPsocket sock;
  std::list<std::string> owned_teams;

  DistantComputer::state_t state;

  int packet_size;
  int packet_received;
  char* packet;
public:
  bool force_disconnect;

  DistantComputer(TCPsocket new_sock);
  ~DistantComputer();

  bool SocketReady() const;
  int ReceiveDatas(char* & buf);
  void SendDatas(char* paket, int size);

  std::string GetAddress();
  std::string nickname;

  void ManageTeam(Action* team);
  void SendChatMessage(Action* a) const;

  void SetState(DistantComputer::state_t _state);
  DistantComputer::state_t GetState() const;
};

#endif
